@@ -13,7 +13,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- *  Copyright (C) 2006-2012 XNeur Team
+ *  Copyright (C) 2006-2016 XNeur Team
  *
  */
 
@@ -323,8 +323,10 @@ static gboolean save_regexp(GtkTreeModel *model, GtkTreePath *path, GtkTreeIter
 	fputs("\n", stream);
 
 	// end write
-	g_free(letters);
-	g_free(condition);
+	if (letters != NULL)
+		g_free(letters);
+	if (condition != NULL)
+		g_free(condition);
 
 	return FALSE;
 }
@@ -345,7 +347,8 @@ void on_okbutton_clicked(GtkButton *button, gpointer user_data)
 	
 	GtkWidget *window = GTK_WIDGET(gtk_builder_get_object (((xyz_t *) user_data)->x, "dialog1"));
 	gtk_widget_destroy(window);
-	g_free(user_data);
+	if (user_data!= NULL)
+		g_free(user_data);
 }
 
 void on_cancelbutton_clicked(GtkButton *button, gpointer user_data)
@@ -354,7 +357,8 @@ void on_cancelbutton_clicked(GtkButton *button, gpointer user_data)
 
 	GtkWidget *window = GTK_WIDGET(gtk_builder_get_object (((xyz_t *) user_data)->x, "dialog1"));
 	gtk_widget_destroy(window);
-	g_free(user_data);
+	if (user_data != NULL)
+		g_free(user_data);
 }
 
 // Parse keyboard binds
@@ -369,9 +373,12 @@ gboolean on_key_press_event(GtkWidget *widget, GdkEventKey *event, gpointer user
 
 	gtk_entry_set_text(GTK_ENTRY(widget), mkey);
 
-	g_free(mkey);
-	g_free(keycode);
-	g_free(modifiers);
+	if (mkey != NULL)
+		g_free(mkey);
+	if (keycode != NULL)
+		g_free(keycode);
+	if (modifiers != NULL)
+		g_free(modifiers);
 		
 	return FALSE;
 }
