@@ -20,7 +20,12 @@
 #ifndef _CONFIGURATION_H_
 #define _CONFIGURATION_H_
 
-#define DEFAULT_RENDERING_ENGINE "AppIndicator"
+#ifdef HAVE_APP_INDICATOR
+	#define DEFAULT_RENDERING_ENGINE "AppIndicator"
+#else
+	#define DEFAULT_RENDERING_ENGINE "StatusIcon"
+#endif
+
 #define DEFAULT_SHOW_IN_THE_TRAY "Flag"
 #define DEFAULT_DELAY 0
 #define DEFAULT_KEYBOARD_PROPERTIES KB_PROP_COMMAND
